@@ -11,6 +11,13 @@ Simple interface, simple deploy.
 
 """
 
+import sys
+
+if len(sys.argv) > 1 and sys.argv[1] != "run":
+    from gevent import monkey
+
+    monkey.patch_all()
+
 import mf
 from dns import resolver as dns
 from webagt import ConnectionError, get
