@@ -163,7 +163,7 @@ class Bootstrap:
             # XXX console.print("No machines found")
             versions = web.host.Machine.versions
             start_time = time.time()
-            total_time = 12
+            total_time = 13
             with console.status(f"[bold green]{total_time} min remaining") as status:
 
                 def update_status():
@@ -171,7 +171,10 @@ class Bootstrap:
                         remaining_time = total_time - round(
                             (time.time() - start_time) / 60
                         )
-                        status.update(f"[bold green]{remaining_time} min remaining")
+                        if remaining_time < 1:
+                            status.update("Finishing up..")
+                            return
+                        status.update(f"[bold green]{remaining_time} minutes remaining")
                         gevent.sleep(1)
 
                 gevent.spawn(update_status)
@@ -188,13 +191,13 @@ class Bootstrap:
                 console.print("Installing python")
                 machine.setup_python()
                 console.print("Installing tor")
-                protected_path = machine.setup_tor()
+                machine.setup_tor()
                 console.print("Installing nginx")
-                protected_path = machine.setup_nginx()
+                machine.setup_nginx()
                 console.print(f"Installing application: {self.package}")
-                machine.setup_app(protected_path, self.package)
+                machine.setup_app(self.package)
 
-                webbrowser.open(f"http://{machine.address}/{protected_path}")
+                webbrowser.open(f"http://{machine.address}")
 
                 machines.append(machine.address)
                 update_config(machines=machines)
