@@ -262,15 +262,24 @@ class MachineBase:
         yield Directory()
 
     @contextmanager
-    def supervisor(self, local_conf_name, system_conf_name):
+    def supervisor(
+        self,
+        # local_conf_name,
+        section,
+    ):
         """Return a context manager that provides access to Supervisor config files."""
         config = configparser.ConfigParser()
         yield config
-        local_conf = f"{local_conf_name}.conf"
+        # local_conf = f"{local_conf_name}.conf"
         output = io.StringIO()
         config.write(output)
-        self.run(f"cat > {local_conf}", stdin=output.getvalue())
-        self.run(f"ln -sf {local_conf} /etc/supervisor/conf.d/{system_conf_name}.conf")
+
+        self.run(
+            f"cat > /etc/supervisor/conf.d/{section}.conf", stdin=output.getvalue()
+        )
+        # self.run(f"cat > {local_conf}", stdin=output.getvalue())
+        # self.run(f"ln -sf {local_conf} /etc/supervisor/conf.d/{section}.conf")
+
         self.run("supervisorctl", "reread")
         self.run("supervisorctl", "update")
 
@@ -340,9 +349,39 @@ class Machine(MachineBase):
         super().__init__(*args, **kwargs)
         self.nginx_dir = self.system_dir / "nginx"
         self.python_dir = self.system_dir / "python"
-        self.runinenv = self.system_dir / "runinenv"
+        self.runinenv = "/home/gaea/runinenv"
         self.projects_dir = self.system_dir / "projects"
 
+    def setup_python(self):
+        """
+        Install Python (w/ SQLite extensions) for application runtime.
+
+        Additionally create a `runinenv` for running things inside virtual environments.
+
+        """
+        self._build(
+            "python.org/ftp/python/{0}/Python-{0}.tar.xz".format(
+                self.versions["python"]
+            ),
+            # TODO "--enable-optimizations",  # NOTE adds 9 minutes
+            "--enable-loadable-sqlite-extensions",
+            # f"--prefix={self.python_dir}",
+        )
+        self.run(
+            f"cat > {self.runinenv}",
+            stdin=textwrap.dedent(
+                """\
+                #!/usr/bin/env bash
+                VENV=$1
+                . ${VENV}/bin/activate
+                shift 1
+                exec "$@"
+                deactivate"""
+            ),
+        )
+        self.run(f"chown gaea:gaea {self.runinenv}")
+        self.run(f"chmod +x {self.runinenv}")
+
     def setup_tor(self):
         """Install Tor for anonymous routing."""
         self._apt("install -yq tor")
@@ -370,137 +409,99 @@ class Machine(MachineBase):
         self.nginx_conf = "/etc/nginx/nginx.conf"
         self.web_data = "/var/www"
         self.open_ports(80, 443)
-        protected_path = newmath.nbrandom(5)
         self.run(f"mkdir {self.web_data}")
-        self.run(
-            f"cat > {self.web_data}/{protected_path}.html",
-            stdin=str(templates.nginx_index(self.address)),
-        )
         self.run(
             f"cat > {self.nginx_conf}",
             stdin=str(templates.nginx_conf(self.address, self.onion)),
         )
         self.run("service nginx restart")
         self.generate_dhparam(512)  # NOTE 2048 adds ? minutes
-        return protected_path
 
     def generate_dhparam(self, bits=4096):
         """Generate a unique Diffie-Hellman prime for Nginx."""
         self.run(f"openssl dhparam -out {self.system_dir}/dhparam.pem {bits}")
 
-    def setup_python(self):
-        """
-        Install Python (w/ SQLite extensions) for application runtime.
-
-        Additionally create a `runinenv` for running things inside virtual environments.
-
-        """
-        self._build(
-            "python.org/ftp/python/{0}/Python-{0}.tar.xz".format(
-                self.versions["python"]
-            ),
-            # TODO "--enable-optimizations",  # NOTE adds 9 minutes
-            "--enable-loadable-sqlite-extensions",
-            f"--prefix={self.python_dir}",
-        )
-        self.run(
-            f"cat > {self.runinenv}",
-            stdin=textwrap.dedent(
-                """\
-                #!/usr/bin/env bash
-                VENV=$1
-                . ${VENV}/bin/activate
-                shift 1
-                exec "$@"
-                deactivate"""
-            ),
-        )
-        self.run(f"chmod +x {self.runinenv}")
-
-    def setup_app(self, protected_path, package):
+    def setup_app(self, package):
         """Install administrative interface."""
-        self.run("/root/python/bin/python3 -m venv app")
-        self.run(f"/root/runinenv app pip install {package}")
-        # TODO put web.host.admin:app behind supervisor
-        # TODO move nginx conf to conf.d's
-        #   TODO replace initial IP-site conf.d with admin server
-        # XXX self.run(
-        # XXX     f"cat > {self.torrc}",
-        # XXX     stdin=textwrap.dedent(
-        # XXX         f"""\
-        # XXX         HiddenServiceDir {self.tor_data}/main
-        # XXX         HiddenServicePort 80 127.0.0.1:80
+        self.user = "gaea"
+        self.run("python3 -m venv app")
+        env_dir = "/home/gaea/app"
+        run_dir = f"{env_dir}/run"
+        self.run(f"{self.runinenv} app pip install {package}")
+        with self.supervisor(package) as config:
+            config["program:app"] = {
+                "autostart": "true",
+                "command": (
+                    f"{self.runinenv} {env_dir} gunicorn {package}:app "
+                    f"-k gevent -w 2 --bind unix:{run_dir}/gunicorn.sock"
+                ),
+                "directory": run_dir,
+                "stopsignal": "INT",
+                "user": "gaea",
+            }
 
-        # XXX         # leave this here for cat'ing over SSH..."""
-        # XXX     ),
-        # XXX )
+    # def install_project(self, registrar, project_root=Path(".")):
+    #     """Install sites from project in `project_root`."""
+    #     # TODO install from Git URL
+    #     with (project_root / "pyproject.toml").open() as fp:
+    #         project = toml.load(fp)["tool"]["poetry"]
+    #     try:
+    #         sites = project["plugins"]["websites"]
+    #     except KeyError:
+    #         console.print("No sites found in `pyproject.toml`.")
+    #         return
+    #     name = project["name"]
+    #     wheel = sorted((project_root / "dist").glob("*.whl"))[-1].name
+    #     console.print(f"Installing project `{name}`")
+    #     project_dir = self.projects_dir / name
+    #     env_dir = f"{project_dir}/env"
+    #     data_dir = f"{project_dir}/data"
+    #     dist_dir = f"{project_dir}/dist"
+    #     certs_dir = f"{project_dir}/certs"
+    #     challenges_dir = f"{project_dir}/certs/challenges"
 
-    # def setup_node(self):
-    #     """Install Node from NodeSource."""
-    #     ...
-
-    def install_project(self, registrar, project_root=Path(".")):
-        """Install sites from project in `project_root`."""
-        # TODO install from Git URL
-        with (project_root / "pyproject.toml").open() as fp:
-            project = toml.load(fp)["tool"]["poetry"]
-        try:
-            sites = project["plugins"]["websites"]
-        except KeyError:
-            console.print("No sites found in `pyproject.toml`.")
-            return
-        name = project["name"]
-        wheel = sorted((project_root / "dist").glob("*.whl"))[-1].name
-        console.print(f"Installing project `{name}`")
-        project_dir = self.projects_dir / name
-        env_dir = f"{project_dir}/env"
-        data_dir = f"{project_dir}/data"
-        dist_dir = f"{project_dir}/dist"
-        certs_dir = f"{project_dir}/certs"
-        challenges_dir = f"{project_dir}/certs/challenges"
-
-        # self.run(f"mkdir {data_dir} {dist_dir} {challenges_dir} -p")
-        # self.run(f"{self.python_dir}/bin/python3 -m venv {env_dir}")
-        # self.cp(f"dist/{wheel}", dist_dir)
-        # self.run(f"{self.runinenv} {env_dir} pip install {dist_dir}/{wheel}")
-        with self.supervisor(f"{self.projects_dir}/{name}", name) as config:
-            for domain, obj in sites.items():
-                domain = domain.replace("_", ".")
-                console.print(f"Pointing https://{domain} to `{obj}`")
-                d = webagt.uri.parse(domain)
-                registrar.create_record(
-                    f"{d.domain}.{d.suffix}", self.address, d.subdomain
-                )
-                config[f"program:{domain}-app"] = {
-                    "autostart": "true",
-                    "command": (
-                        f"{self.runinenv} {env_dir} gunicorn {obj} "
-                        f"-k gevent -w 2 --bind unix:{project_dir}/gunicorn.sock"
-                    ),
-                    "directory": data_dir,
-                    "stopsignal": "INT",
-                    "user": "root",
-                }
-                # config[f"program:{domain}-jobs"] = {
-                #     "autostart": "true",
-                #     "command": f"{self.runinenv} {env_dir} loveliness serve",
-                #     "directory": data_dir,
-                #     "stopsignal": "INT",
-                #     "user": "root",
-                # }
-                # TODO create non-TLS nginx config for let's encrypting domain
-                # TODO reload nginx
-                # TODO initiate let's encrypt flow
-                # TODO replace non-TLS nginx config with TLS-based config
-                # TODO reload nginx
-                local_nginx = project_dir / "nginx.conf"
-                system_nginx = self.nginx_dir / f"conf/conf.d/project_{name}.conf"
-                print("local", local_nginx)
-                print("system", system_nginx)
-                C = str(templates.nginx_site(domain, project_dir, self.ssl_ciphers))
-                print(C)
-                self.run(
-                    f"cat > {local_nginx}",
-                    stdin=C,
-                )
-                self.run(f"ln -sf {local_nginx} {system_nginx}")
+    #     # self.run(f"mkdir {data_dir} {dist_dir} {challenges_dir} -p")
+    #     # self.run(f"{self.python_dir}/bin/python3 -m venv {env_dir}")
+    #     # self.cp(f"dist/{wheel}", dist_dir)
+    #     # self.run(f"{self.runinenv} {env_dir} pip install {dist_dir}/{wheel}")
+    #     with self.supervisor(f"{self.projects_dir}/{name}", name) as config:
+    #         for domain, obj in sites.items():
+    #             domain = domain.replace("_", ".")
+    #             console.print(f"Pointing https://{domain} to `{obj}`")
+    #             d = webagt.uri.parse(domain)
+    #             registrar.create_record(
+    #                 f"{d.domain}.{d.suffix}", self.address, d.subdomain
+    #             )
+    #             config[f"program:{domain}-app"] = {
+    #                 "autostart": "true",
+    #                 "command": (
+    #                     f"{self.runinenv} {env_dir} gunicorn {obj} "
+    #                     f"-k gevent -w 2 --bind unix:{project_dir}/gunicorn.sock"
+    #                 ),
+    #                 "directory": data_dir,
+    #                 "stopsignal": "INT",
+    #                 "user": "root",
+    #             }
+    #             # config[f"program:{domain}-jobs"] = {
+    #             #     "autostart": "true",
+    #             #     "command": f"{self.runinenv} {env_dir} loveliness serve",
+    #             #     "directory": data_dir,
+    #             #     "stopsignal": "INT",
+    #             #     "user": "root",
+    #             # }
+    #             # TODO create non-TLS nginx config for let's encrypting domain
+    #             # TODO reload nginx
+    #             # TODO initiate let's encrypt flow
+    #             # TODO replace non-TLS nginx config with TLS-based config
+    #             # TODO reload nginx
+    #             local_nginx = project_dir / "nginx.conf"
+    #             system_nginx = self.nginx_dir / f"conf/conf.d/project_{name}.conf"
+    #             print("local", local_nginx)
+    #             print("system", system_nginx)
+    #             C = str(templates.nginx_site(domain, project_dir, self.ssl_ciphers))
+    #             print(C)
+    #             self.run(
+    #                 f"cat > {local_nginx}",
+    #                 stdin=C,
+    #             )
+    #             self.run(f"ln -sf {local_nginx} {system_nginx}")
